c**********************************************************************
c GETACCH_MIG.F
c**********************************************************************
c Apply a drag acceleration to simulate planetary migration.
c
c See: Malhotra, R., Astron. J., 110, 1, 420-429 (1995)
c
c Input:
c
c  nbod		number of PL's
c  axh,ayh,azh	accelerations in heliocentric frame (calculated so far)
c
c  in common block /migration/
c  see migration.inc
c
c Output:
c
c  axh,ayh,azh	new accelerations with the drag ADDED
c
c Remarks: 
c Author: Miroslav Broz, miroslav.broz@email.cz
c Date: Dec 19th 2007

      subroutine getacch_mig(nbod,axh,ayh,azh)

      include '../swift.inc'
      include 'migration.inc'

c  input/output
      integer nbod
      real*8 axh(NPLMAX),ayh(NPLMAX),azh(NPLMAX)

c  internals
      integer i
      real*8 norm,koef

c  common blocks
      real*8 t_cb
      common /times/ t_cb

      real*8 vxh_cb(NPLMAX),vyh_cb(NPLMAX),vzh_cb(NPLMAX)
      common /velocities/ vxh_cb,vyh_cb,vzh_cb

c  main ----------------------------------------------------------

      do i = 2,nbod
        if (t_cb.gt.t0(i)) then

c  normalize the velocities first
          norm = sqrt(vxh_cb(i)**2 + vyh_cb(i)**2 + vzh_cb(i)**2)

c  compute the drag coefficient
          koef = k_migration(i) * exp(-(t_cb-t0(i))/tau(i)) / norm
          axh(i) = axh(i) + vxh_cb(i) * koef
          ayh(i) = ayh(i) + vyh_cb(i) * koef
          azh(i) = azh(i) + vzh_cb(i) * koef

        endif
      enddo

      end    ! getacch_mig
c-----------------------------------------------------------------


