c**********************************************************************
c IO_INIT_MIGRATION.F
c**********************************************************************
c Read parameters of planetary migration, precompute coefficients.
c
c See: Malhotra, R., Astron. J., 110, 1, 420-429 (1995)
c
c Input:
c  infile	name of the migration parameters input file,
c		for structure of this file refer to example migration.in
c  npl		number of PL's (due to check the buffer size)
c
c Output:
c
c  in common block /migration/
c  see migration.inc
c
c Remarks: 
c Author: Miroslav Broz, miroslav.broz@email.cz
c Date: Dec 19th 2007

      subroutine io_init_migration(infile,nbod,mass)

      include '../swift.inc'
      include 'migration.inc'

c  input
      character*80 infile
      integer nbod
      real*8 mass(NPLMAX)

c  internals
      integer i,ierr
      real*8 a_i, a_f

c  main ----------------------------------------------------------

c  read input parameters
      write(*,*) 'Migration parameters file called ',infile
      call io_open(7,infile,'old','formatted',ierr)
      if (ierr.ne.0) then
        write(*,*) 'io_init_migration: Error opening file ',infile,'.'
        call util_exit(1)
      endif

      do i=2,nbod
        read(7,*) a_i, a_f, tau(i), t0(i)
        tau(i) = tau(i)*365.25d6        ! Myr -> days
        t0(i) = t0(i)*365.25d6          ! Myr -> days
        k_migration(i) = - (sqrt(mass(1)/a_f) - sqrt(mass(1)/a_i))
     :    / tau(i)
      enddo

      close(unit = 7)
      write(*,*) ' '

      return
      end    ! io_init_migration
c-----------------------------------------------------------------


